==> symbol-processing-aa-embeddable-2.1.0-1.0.29-sources.jar: org/jetbrains/kotlin/cli/jvm/compiler/CliVirtualFileFinderFactory.kt <==
/*
 * Copyright 2010-2016 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package ksp.org.jetbrains.kotlin.cli.jvm.compiler

import ksp.com.intellij.openapi.project.Project
import ksp.com.intellij.psi.search.GlobalSearchScope
import ksp.org.jetbrains.kotlin.cli.jvm.index.JvmDependenciesIndex
import ksp.org.jetbrains.kotlin.descriptors.ModuleDescriptor
import ksp.org.jetbrains.kotlin.load.kotlin.VirtualFileFinder
import ksp.org.jetbrains.kotlin.load.kotlin.VirtualFileFinderFactory

// TODO: create different JvmDependenciesIndex instances for different sets of source roots to improve performance
class CliVirtualFileFinderFactory(private val index: JvmDependenciesIndex, private val enableSearchInCtSym: Boolean) : VirtualFileFinderFactory {
    override fun create(scope: GlobalSearchScope): VirtualFileFinder = CliVirtualFileFinder(index, scope, enableSearchInCtSym)

    override fun create(project: Project, module: ModuleDescriptor): VirtualFileFinder =
        CliVirtualFileFinder(index, GlobalSearchScope.allScope(project), enableSearchInCtSym)
}

==> symbol-processing-aa-embeddable-2.3.3-sources.jar: org/jetbrains/kotlin/cli/jvm/compiler/CliVirtualFileFinderFactory.kt <==
/*
 * Copyright 2010-2016 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package ksp.org.jetbrains.kotlin.cli.jvm.compiler

import ksp.com.intellij.openapi.project.Project
import ksp.com.intellij.psi.search.GlobalSearchScope
import ksp.org.jetbrains.kotlin.analyzer.ModuleInfo
import ksp.org.jetbrains.kotlin.cli.jvm.index.JvmDependenciesIndex
import ksp.org.jetbrains.kotlin.load.kotlin.VirtualFileFinder
import ksp.org.jetbrains.kotlin.load.kotlin.VirtualFileFinderFactory
import ksp.org.jetbrains.kotlin.util.PerformanceManager

// TODO: create different JvmDependenciesIndex instances for different sets of source roots to improve performance
class CliVirtualFileFinderFactory(
    private val index: JvmDependenciesIndex,
    private val enableSearchInCtSym: Boolean,
    private val perfManager: PerformanceManager?,
) : VirtualFileFinderFactory {
    override fun create(scope: GlobalSearchScope): VirtualFileFinder =
        CliVirtualFileFinder(index, scope, enableSearchInCtSym, perfManager)

    override fun create(project: Project, module: ModuleInfo): VirtualFileFinder =
        CliVirtualFileFinder(index, GlobalSearchScope.allScope(project), enableSearchInCtSym, perfManager)
}
